@@ -76,9 +76,6 @@ typedef struct {
 	gint		 inhibit_cookie;
 } GcmCalibratePriv;
 
-/**
- * gcm_window_set_parent_xid:
- **/
 static void
 gcm_window_set_parent_xid (GtkWindow *window, guint32 xid)
 {
@@ -106,9 +103,6 @@ gcm_window_set_parent_xid (GtkWindow *window, guint32 xid)
 	gtk_window_set_title (window, "");
 }
 
-/**
- * gcm_calib_activate_cb:
- **/
 static void
 gcm_calib_activate_cb (GApplication *application, GcmCalibratePriv *priv)
 {
@@ -128,9 +122,6 @@ gcm_calib_confirm_quit_cb (GtkDialog *dialog,
 	g_application_release (G_APPLICATION (priv->application));
 }
 
-/**
- * gcm_calib_confirm_quit:
- **/
 static void
 gcm_calib_confirm_quit (GcmCalibratePriv *priv)
 {
@@ -162,9 +153,6 @@ gcm_calib_confirm_quit (GcmCalibratePriv *priv)
 	gtk_widget_show (dialog);
 }
 
-/**
- * gcm_calib_delete_event_cb:
- **/
 static gboolean
 gcm_calib_delete_event_cb (GtkWidget *widget, GdkEvent *event, GcmCalibratePriv *priv)
 {
@@ -172,27 +160,18 @@ gcm_calib_delete_event_cb (GtkWidget *widget, GdkEvent *event, GcmCalibratePriv
 	return FALSE;
 }
 
-/**
- * gcm_calib_assistant_cancel_cb:
- **/
 static void
 gcm_calib_assistant_cancel_cb (GtkAssistant *assistant, GcmCalibratePriv *priv)
 {
 	gcm_calib_confirm_quit (priv);
 }
 
-/**
- * gcm_calib_assistant_close_cb:
- **/
 static void
 gcm_calib_assistant_close_cb (GtkAssistant *assistant, GcmCalibratePriv *priv)
 {
 	g_application_release (G_APPLICATION (priv->application));
 }
 
-/**
- * gcm_calib_play_sound:
- **/
 static void
 gcm_calib_play_sound (GcmCalibratePriv *priv)
 {
@@ -207,9 +186,6 @@ gcm_calib_play_sound (GcmCalibratePriv *priv)
 }
 
 
-/**
- * gcm_calib_get_vbox_for_page:
- **/
 static GtkWidget *
 gcm_calib_get_vbox_for_page (GcmCalibratePriv *priv,
 			     GcmCalibratePage page)
@@ -319,7 +295,7 @@ gcm_calib_set_extra_metadata (GcmCalibratePriv *priv,
 	/* add the calibration brightness if an internal panel */
 	percentage = gcm_calibrate_get_screen_brightness (priv->calibrate);
 	if (percentage > 0) {
-		screen_brightness_str = g_strdup_printf ("%i", percentage);
+		screen_brightness_str = g_strdup_printf ("%u", percentage);
 		_cmsDictAddEntryAscii (dict,
 				       CD_PROFILE_METADATA_SCREEN_BRIGHTNESS,
 				       screen_brightness_str);
@@ -350,9 +326,6 @@ out:
 	return ret;
 }
 
-/**
- * gcm_calib_set_sensor_options_cb:
- **/
 static void
 gcm_calib_set_sensor_options_cb (GObject *object,
 				 GAsyncResult *res,
@@ -544,9 +517,6 @@ gcm_calib_assistant_page_forward_cb (gint current_page, gpointer user_data)
 	return current_page;
 }
 
-/**
- * gcm_calib_assistant_prepare_cb:
- **/
 static gboolean
 gcm_calib_assistant_prepare_cb (GtkAssistant *assistant,
 				GtkWidget *page_widget,
@@ -599,9 +569,6 @@ gcm_calib_assistant_prepare_cb (GtkAssistant *assistant,
 	return FALSE;
 }
 
-/**
- * gcm_calib_add_page_title:
- **/
 static GtkWidget *
 gcm_calib_add_page_title (GcmCalibratePriv *priv, const gchar *text)
 {
@@ -648,9 +615,6 @@ gcm_calib_label_activate_link_cb (GtkLabel *label,
 	return ret;
 }
 
-/**
- * gcm_calib_add_page_para:
- **/
 static GtkWidget *
 gcm_calib_add_page_para (GtkWidget *vbox, const gchar *text)
 {
@@ -664,7 +628,8 @@ gcm_calib_add_page_para (GtkWidget *vbox, const gchar *text)
 	gtk_label_set_markup (GTK_LABEL (label), text);
 	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
 	gtk_label_set_width_chars (GTK_LABEL (label), 40);
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0f, 0.0f);
+	gtk_label_set_xalign (GTK_LABEL (label), 0.f);
+	gtk_label_set_yalign (GTK_LABEL (label), 0.f);
 
 	/* make left aligned */
 	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
@@ -673,9 +638,6 @@ gcm_calib_add_page_para (GtkWidget *vbox, const gchar *text)
 	return label;
 }
 
-/**
- * gcm_calib_add_page_bullet:
- **/
 static void
 gcm_calib_add_page_bullet (GtkWidget *vbox, const gchar *text)
 {
@@ -684,9 +646,6 @@ gcm_calib_add_page_bullet (GtkWidget *vbox, const gchar *text)
 	gcm_calib_add_page_para (vbox, markup);
 }
 
-/**
- * gcm_calib_setup_page_intro:
- **/
 static void
 gcm_calib_setup_page_intro (GcmCalibratePriv *priv)
 {
@@ -747,9 +706,6 @@ gcm_calib_setup_page_intro (GcmCalibratePriv *priv)
 	gtk_widget_show_all (vbox);
 }
 
-/**
- * gcm_calibrate_is_livecd:
- **/
 static gboolean
 gcm_calibrate_is_livecd (void)
 {
@@ -770,9 +726,6 @@ gcm_calibrate_is_livecd (void)
 #endif
 }
 
-/**
- * gcm_calib_show_profile_button_clicked_cb:
- **/
 static void
 gcm_calib_show_profile_button_clicked_cb (GtkButton *button,
 					  GcmCalibratePriv *priv)
@@ -798,9 +751,6 @@ gcm_calib_show_profile_button_clicked_cb (GtkButton *button,
 	}
 }
 
-/**
- * gcm_calib_get_show_profile_button:
- **/
 static GtkWidget *
 gcm_calib_get_show_profile_button (GcmCalibratePriv *priv)
 {
@@ -834,9 +784,6 @@ gcm_calib_get_show_profile_button (GcmCalibratePriv *priv)
 	return button;
 }
 
-/**
- * gcm_calib_setup_page_summary:
- **/
 static void
 gcm_calib_setup_page_summary (GcmCalibratePriv *priv)
 {
@@ -908,9 +855,6 @@ gcm_calib_setup_page_summary (GcmCalibratePriv *priv)
 	gtk_widget_show_all (vbox);
 }
 
-/**
- * gcm_calib_setup_page_action:
- **/
 static void
 gcm_calib_setup_page_action (GcmCalibratePriv *priv)
 {
@@ -964,9 +908,6 @@ gcm_calib_setup_page_action (GcmCalibratePriv *priv)
 	gtk_widget_hide (priv->action_image);
 }
 
-/**
- * gcm_calib_setup_page_display_configure_wait:
- **/
 static void
 gcm_calib_setup_page_display_configure_wait (GcmCalibratePriv *priv)
 {
@@ -1022,9 +963,6 @@ if(0)	gcm_calib_add_page_bullet (content, _("Adjust the display brightness to a
 	gtk_widget_show_all (vbox);
 }
 
-/**
- * gcm_calib_button_clicked_install_argyllcms_cb:
- **/
 static void
 gcm_calib_button_clicked_install_argyllcms_cb (GtkButton *button, GcmCalibratePriv *priv)
 {
@@ -1046,9 +984,6 @@ gcm_calib_button_clicked_install_argyllcms_cb (GtkButton *button, GcmCalibratePr
 	}
 }
 
-/**
- * gcm_calib_setup_page_install_argyllcms:
- **/
 static void
 gcm_calib_setup_page_install_argyllcms (GcmCalibratePriv *priv)
 {
@@ -1098,9 +1033,6 @@ gcm_calib_setup_page_install_argyllcms (GcmCalibratePriv *priv)
 	gtk_widget_show_all (vbox);
 }
 
-/**
- * gcm_calib_button_clicked_install_targets_cb:
- **/
 static void
 gcm_calib_button_clicked_install_targets_cb (GtkButton *button, GcmCalibratePriv *priv)
 {
@@ -1121,9 +1053,6 @@ gcm_calib_button_clicked_install_targets_cb (GtkButton *button, GcmCalibratePriv
 	}
 }
 
-/**
- * gcm_calib_setup_page_install_targets:
- **/
 static void
 gcm_calib_setup_page_install_targets (GcmCalibratePriv *priv)
 {
@@ -1176,9 +1105,6 @@ gcm_calib_setup_page_install_targets (GcmCalibratePriv *priv)
 }
 
 
-/**
- * gcm_calib_reference_kind_to_localised_string:
- **/
 static const gchar *
 gcm_calib_reference_kind_to_localised_string (GcmCalibrateReferenceKind kind)
 {
@@ -1225,9 +1151,6 @@ gcm_calib_reference_kind_to_localised_string (GcmCalibrateReferenceKind kind)
 	return NULL;
 }
 
-/**
- * gcm_calib_reference_kind_to_image_filename:
- **/
 static const gchar *
 gcm_calib_reference_kind_to_image_filename (GcmCalibrateReferenceKind kind)
 {
@@ -1254,9 +1177,6 @@ gcm_calib_reference_kind_to_image_filename (GcmCalibrateReferenceKind kind)
 	return NULL;
 }
 
-/**
- * gcm_calib_reference_kind_combobox_cb:
- **/
 static void
 gcm_calib_reference_kind_combobox_cb (GtkComboBox *combo_box,
 				      GcmCalibratePriv *priv)
@@ -1280,9 +1200,6 @@ gcm_calib_reference_kind_combobox_cb (GtkComboBox *combo_box,
 	gtk_image_set_from_file (GTK_IMAGE (priv->reference_preview), path);
 }
 
-/**
- * gcm_calib_setup_page_target_kind:
- **/
 static void
 gcm_calib_setup_page_target_kind (GcmCalibratePriv *priv)
 {
@@ -1375,9 +1292,6 @@ gcm_calib_display_kind_toggled_cb (GtkToggleButton *togglebutton,
 		      NULL);
 }
 
-/**
- * gcm_calib_setup_page_display_kind:
- **/
 static void
 gcm_calib_setup_page_display_kind (GcmCalibratePriv *priv)
 {
@@ -1497,9 +1411,6 @@ gcm_calib_display_temp_toggled_cb (GtkToggleButton *togglebutton,
 		      NULL);
 }
 
-/**
- * gcm_calib_setup_page_display_temp:
- **/
 static void
 gcm_calib_setup_page_display_temp (GcmCalibratePriv *priv)
 {
@@ -1593,9 +1504,6 @@ gcm_calib_print_kind_toggled_cb (GtkToggleButton *togglebutton,
 		      NULL);
 }
 
-/**
- * gcm_calib_setup_page_print_kind:
- **/
 static void
 gcm_calib_setup_page_print_kind (GcmCalibratePriv *priv)
 {
@@ -1675,9 +1583,6 @@ gcm_calib_precision_toggled_cb (GtkToggleButton *togglebutton,
 		      NULL);
 }
 
-/**
- * gcm_calib_setup_page_precision:
- **/
 static void
 gcm_calib_setup_page_precision (GcmCalibratePriv *priv)
 {
@@ -1725,8 +1630,8 @@ gcm_calib_setup_page_precision (GcmCalibratePriv *priv)
 			g_string_append (labels[i], " ");
 			/* TRANSLATORS: radio options for calibration precision */
 			g_string_append_printf (labels[i], ngettext (
-						"(about %i sheet of paper)",
-						"(about %i sheets of paper)",
+						"(about %u sheet of paper)",
+						"(about %u sheets of paper)",
 						values_printer[i]),
 						values_printer[i]);
 		}
@@ -1736,8 +1641,8 @@ gcm_calib_setup_page_precision (GcmCalibratePriv *priv)
 			g_string_append (labels[i], " ");
 			/* TRANSLATORS: radio options for calibration precision */
 			g_string_append_printf (labels[i], ngettext (
-						"(about %i minute)",
-						"(about %i minutes)",
+						"(about %u minute)",
+						"(about %u minutes)",
 						values_display[i]),
 						values_display[i]);
 		}
@@ -1800,16 +1705,13 @@ gcm_calib_text_changed_cb (GtkEntry *entry,
 		      NULL);
 }
 
-/**
- * gcm_calib_setup_page_profile_title:
- **/
 static void
 gcm_calib_setup_page_profile_title (GcmCalibratePriv *priv)
 {
 	GtkWidget *vbox;
 	GtkWidget *content;
 	GtkWidget *widget;
-	gchar *tmp = NULL;
+	g_autofree gchar *tmp = NULL;
 	GtkAssistant *assistant = GTK_ASSISTANT (priv->main_window);
 
 	/* TRANSLATORS: this is the page title */
@@ -1831,7 +1733,6 @@ gcm_calib_setup_page_profile_title (GcmCalibratePriv *priv)
 		      "description", &tmp,
 		      NULL);
 	gtk_entry_set_text (GTK_ENTRY (widget), tmp);
-	g_free (tmp);
 
 	/* watch for changes */
 	g_signal_connect (GTK_EDITABLE (widget), "changed",
@@ -1852,9 +1753,6 @@ gcm_calib_setup_page_profile_title (GcmCalibratePriv *priv)
 	gtk_widget_show_all (vbox);
 }
 
-/**
- * gcm_calib_setup_page_sensor:
- **/
 static void
 gcm_calib_setup_page_sensor (GcmCalibratePriv *priv)
 {
@@ -1887,9 +1785,6 @@ gcm_calib_setup_page_sensor (GcmCalibratePriv *priv)
 	gtk_widget_show_all (vbox);
 }
 
-/**
- * gcm_calib_setup_page_failure:
- **/
 static void
 gcm_calib_setup_page_failure (GcmCalibratePriv *priv)
 {
@@ -1922,9 +1817,6 @@ gcm_calib_setup_page_failure (GcmCalibratePriv *priv)
 	gtk_widget_show_all (vbox);
 }
 
-/**
- * gcm_calib_got_sensor:
- **/
 static void
 gcm_calib_got_sensor (GcmCalibratePriv *priv, CdSensor *sensor)
 {
@@ -1958,9 +1850,6 @@ gcm_calib_got_sensor (GcmCalibratePriv *priv, CdSensor *sensor)
 	}
 }
 
-/**
- * gcm_calib_get_sensors_cb:
- **/
 static void
 gcm_calib_get_sensors_cb (GObject *object,
 			  GAsyncResult *res,
@@ -1987,9 +1876,6 @@ gcm_calib_get_sensors_cb (GObject *object,
 	}
 }
 
-/**
- * gcm_calib_add_pages:
- **/
 static void
 gcm_calib_add_pages (GcmCalibratePriv *priv)
 {
@@ -2047,9 +1933,6 @@ gcm_calib_add_pages (GcmCalibratePriv *priv)
 			       priv);
 }
 
-/**
- * gcm_calib_sensor_added_cb:
- **/
 static void
 gcm_calib_sensor_added_cb (CdClient *client, CdSensor *sensor, GcmCalibratePriv *priv)
 {
@@ -2058,9 +1941,6 @@ gcm_calib_sensor_added_cb (CdClient *client, CdSensor *sensor, GcmCalibratePriv
 	gtk_assistant_next_page (GTK_ASSISTANT (priv->main_window));
 }
 
-/**
- * gcm_calib_startup_cb:
- **/
 static void
 gcm_calib_startup_cb (GApplication *application, GcmCalibratePriv *priv)
 {
@@ -2111,7 +1991,7 @@ gcm_calib_startup_cb (GApplication *application, GcmCalibratePriv *priv)
 
 	/* set the parent window if it is specified */
 	if (priv->xid != 0) {
-		g_debug ("Setting xid %i", priv->xid);
+		g_debug ("Setting xid %u", priv->xid);
 		gcm_window_set_parent_xid (GTK_WINDOW (priv->main_window), priv->xid);
 	}
 
@@ -2268,9 +2148,6 @@ gcm_calib_interaction_required_cb (GcmCalibrate *calibrate,
 	priv->has_pending_interaction = TRUE;
 }
 
-/**
- * main:
- **/
 int
 main (int argc, char **argv)
 {
