@@ -36,11 +36,6 @@ static void     gcm_calibrate_finalize	(GObject     *object);
 
 #define GCM_CALIBRATE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GCM_TYPE_CALIBRATE, GcmCalibratePrivate))
 
-/**
- * GcmCalibratePrivate:
- *
- * Private #GcmCalibrate data
- **/
 typedef struct
 {
 	GcmBrightness			*brightness;
@@ -124,9 +119,6 @@ gcm_calibrate_get_content_widget (GcmCalibrate *calibrate)
 	return priv->content_widget;
 }
 
-/**
- * gcm_calibrate_mkdir_with_parents:
- **/
 static gboolean
 gcm_calibrate_mkdir_with_parents (const gchar *filename, GError **error)
 {
@@ -141,9 +133,6 @@ gcm_calibrate_mkdir_with_parents (const gchar *filename, GError **error)
 	return TRUE;
 }
 
-/**
- * gcm_calibrate_get_time:
- **/
 static gchar *
 gcm_calibrate_get_time (void)
 {
@@ -159,9 +148,6 @@ gcm_calibrate_get_time (void)
 	return text;
 }
 
-/**
- * gcm_calibrate_get_filename_result:
- **/
 const gchar *
 gcm_calibrate_get_filename_result (GcmCalibrate *calibrate)
 {
@@ -169,9 +155,6 @@ gcm_calibrate_get_filename_result (GcmCalibrate *calibrate)
 	return priv->filename_result;
 }
 
-/**
- * gcm_calibrate_get_working_path:
- **/
 const gchar *
 gcm_calibrate_get_working_path (GcmCalibrate *calibrate)
 {
@@ -179,9 +162,6 @@ gcm_calibrate_get_working_path (GcmCalibrate *calibrate)
 	return priv->working_path;
 }
 
-/**
- * gcm_calibrate_get_basename:
- **/
 const gchar *
 gcm_calibrate_get_basename (GcmCalibrate *calibrate)
 {
@@ -189,9 +169,6 @@ gcm_calibrate_get_basename (GcmCalibrate *calibrate)
 	return priv->basename;
 }
 
-/**
- * gcm_calibrate_get_screen_brightness:
- **/
 guint
 gcm_calibrate_get_screen_brightness (GcmCalibrate *calibrate)
 {
@@ -199,18 +176,15 @@ gcm_calibrate_get_screen_brightness (GcmCalibrate *calibrate)
 	return priv->new_brightness;
 }
 
-/**
- * gcm_calibrate_set_basename:
- **/
 static void
 gcm_calibrate_set_basename (GcmCalibrate *calibrate)
 {
-	gchar *serial = NULL;
-	gchar *manufacturer = NULL;
-	gchar *model = NULL;
-	gchar *timespec = NULL;
+	g_autofree gchar *serial = NULL;
+	g_autofree gchar *manufacturer = NULL;
+	g_autofree gchar *model = NULL;
+	g_autofree gchar *timespec = NULL;
 	GDate *date = NULL;
-	GString *basename;
+	g_autoptr(GString) basename = NULL;
 
 	/* get device properties */
 	g_object_get (calibrate,
@@ -241,16 +215,8 @@ gcm_calibrate_set_basename (GcmCalibrate *calibrate)
 	g_object_set (calibrate, "basename", basename->str, NULL);
 
 	g_date_free (date);
-	g_free (serial);
-	g_free (manufacturer);
-	g_free (model);
-	g_free (timespec);
-	g_string_free (basename, TRUE);
 }
 
-/**
- * gcm_calibrate_set_from_exif:
- **/
 gboolean
 gcm_calibrate_set_from_exif (GcmCalibrate *calibrate, const gchar *filename, GError **error)
 {
@@ -302,15 +268,11 @@ gcm_calibrate_get_sensor (GcmCalibrate *calibrate)
 	return priv->sensor;
 }
 
-/**
- * gcm_calibrate_set_working_path:
- **/
 static gboolean
 gcm_calibrate_set_working_path (GcmCalibrate *calibrate, GError **error)
 {
-	gboolean ret = FALSE;
-	gchar *timespec = NULL;
-	gchar *folder = NULL;
+	g_autofree gchar *timespec = NULL;
+	g_autofree gchar *folder = NULL;
 	GcmCalibratePrivate *priv = GET_PRIVATE (calibrate);
 
 	/* remove old value */
@@ -320,15 +282,9 @@ gcm_calibrate_set_working_path (GcmCalibrate *calibrate, GError **error)
 	timespec = gcm_calibrate_get_time ();
 	folder = g_strjoin (" - ", priv->basename, timespec, NULL);
 	priv->working_path = g_build_filename (g_get_user_config_dir (), "gnome-color-manager", "calibration", folder, NULL);
-	ret = gcm_calibrate_mkdir_with_parents (priv->working_path, error);
-	g_free (timespec);
-	g_free (folder);
-	return ret;
+	return gcm_calibrate_mkdir_with_parents (priv->working_path, error);
 }
 
-/**
- * gcm_calibrate_interaction:
- **/
 void
 gcm_calibrate_interaction (GcmCalibrate *calibrate, GtkResponseType response)
 {
@@ -360,9 +316,6 @@ gcm_calibrate_interaction (GcmCalibrate *calibrate, GtkResponseType response)
 	klass->interaction (calibrate, response);
 }
 
-/**
- * gcm_calibrate_copy_file:
- **/
 static gboolean
 gcm_calibrate_copy_file (const gchar *src,
 			 const gchar *dest,
@@ -383,15 +336,12 @@ gcm_calibrate_copy_file (const gchar *src,
 			    error);
 }
 
-/**
- * gcm_calibrate_interaction_attach:
- **/
 void
 gcm_calibrate_interaction_attach (GcmCalibrate *calibrate)
 {
 	GcmCalibratePrivate *priv = GET_PRIVATE (calibrate);
 	const gchar *filename;
-	GString *message;
+	g_autoptr(GString) message = NULL;
 
 	/* TRANSLATORS: title, instrument is a hardware color calibration sensor */
 	gcm_calibrate_set_title (calibrate,
@@ -429,13 +379,8 @@ gcm_calibrate_interaction_attach (GcmCalibrate *calibrate)
 			 /* TRANSLATORS: this is the application name for libcanberra */
 			 CA_PROP_APPLICATION_NAME, _("GNOME Color Manager"),
 			 CA_PROP_EVENT_DESCRIPTION, "interaction required", NULL);
-
-	g_string_free (message, TRUE);
 }
 
-/**
- * gcm_calibrate_interaction_screen:
- **/
 void
 gcm_calibrate_interaction_screen (GcmCalibrate *calibrate)
 {
@@ -472,9 +417,6 @@ gcm_calibrate_interaction_screen (GcmCalibrate *calibrate)
 			 CA_PROP_EVENT_DESCRIPTION, "correct hardware state", NULL);
 }
 
-/**
- * gcm_calibrate_interaction_calibrate:
- **/
 void
 gcm_calibrate_interaction_calibrate (GcmCalibrate *calibrate)
 {
@@ -514,16 +456,13 @@ gcm_calibrate_interaction_calibrate (GcmCalibrate *calibrate)
 			 CA_PROP_EVENT_DESCRIPTION, "setup calibration tool", NULL);
 }
 
-/**
- * gcm_calibrate_set_brightness:
- **/
 static void
 gcm_calibrate_set_brightness (GcmCalibrate *calibrate, CdDevice *device)
 {
 	GcmCalibratePrivate *priv = GET_PRIVATE (calibrate);
 	const gchar *xrandr_name;
 	gboolean ret;
-	GError *error = NULL;
+	g_autoptr(GError) error = NULL;
 
 	/* is this a laptop */
 	xrandr_name = cd_device_get_metadata_item (device,
@@ -551,13 +490,9 @@ gcm_calibrate_set_brightness (GcmCalibrate *calibrate, CdDevice *device)
 	if (!ret) {
 		g_warning ("failed to set brightness: %s",
 			   error->message);
-		g_error_free (error);
 	}
 }
 
-/**
- * gcm_calibrate_unset_brightness:
- **/
 static void
 gcm_calibrate_unset_brightness (GcmCalibrate *calibrate, CdDevice *device)
 {
@@ -586,9 +521,6 @@ gcm_calibrate_unset_brightness (GcmCalibrate *calibrate, CdDevice *device)
 		g_warning ("failed to set brightness: %s",  error->message);
 }
 
-/**
- * gcm_calibrate_display:
- **/
 static gboolean
 gcm_calibrate_display (GcmCalibrate *calibrate,
 		       CdDevice *device,
@@ -597,10 +529,10 @@ gcm_calibrate_display (GcmCalibrate *calibrate,
 {
 	const gchar *filename_tmp;
 	gboolean ret = TRUE;
-	gchar *cal_fn = NULL;
-	gchar *ti1_dest_fn = NULL;
-	gchar *ti1_src_fn = NULL;
-	gchar *ti3_fn = NULL;
+	g_autofree gchar *cal_fn = NULL;
+	g_autofree gchar *ti1_dest_fn = NULL;
+	g_autofree gchar *ti1_src_fn = NULL;
+	g_autofree gchar *ti3_fn = NULL;
 	GcmCalibrateClass *klass = GCM_CALIBRATE_GET_CLASS (calibrate);
 	GcmCalibratePrivate *priv = GET_PRIVATE (calibrate);
 
@@ -648,16 +580,9 @@ gcm_calibrate_display (GcmCalibrate *calibrate,
 out:
 	/* unset brightness */
 	gcm_calibrate_unset_brightness (calibrate, device);
-	g_free (cal_fn);
-	g_free (ti1_src_fn);
-	g_free (ti1_dest_fn);
-	g_free (ti3_fn);
 	return ret;
 }
 
-/**
- * gcm_calibrate_camera_get_reference_image:
- **/
 static gchar *
 gcm_calibrate_camera_get_reference_image (const gchar *directory, GtkWindow *window)
 {
@@ -702,9 +627,6 @@ gcm_calibrate_camera_get_reference_image (const gchar *directory, GtkWindow *win
 	return filename;
 }
 
-/**
- * gcm_calibrate_camera_get_reference_data:
- **/
 static gchar *
 gcm_calibrate_camera_get_reference_data (const gchar *directory, GtkWindow *window)
 {
@@ -756,9 +678,6 @@ gcm_calibrate_camera_get_reference_data (const gchar *directory, GtkWindow *wind
 	return filename;
 }
 
-/**
- * gcm_calibrate_get_device_for_it8_file:
- **/
 static gchar *
 gcm_calibrate_get_device_for_it8_file (const gchar *filename)
 {
@@ -788,14 +707,11 @@ gcm_calibrate_get_device_for_it8_file (const gchar *filename)
 	return device;
 }
 
-/**
- * gcm_calibrate_file_chooser_get_working_path:
- **/
 static gchar *
 gcm_calibrate_file_chooser_get_working_path (GcmCalibrate *calibrate, GtkWindow *window)
 {
 	GtkWidget *dialog;
-	gchar *current_folder;
+	g_autofree gchar *current_folder = NULL;
 	gchar *working_path = NULL;
 
 	/* start in the correct place */
@@ -820,23 +736,18 @@ gcm_calibrate_file_chooser_get_working_path (GcmCalibrate *calibrate, GtkWindow
 	gtk_widget_destroy (dialog);
 
 	/* or NULL for missing */
-	g_free (current_folder);
 	return working_path;
 }
 
-/**
- * gcm_calibrate_printer:
- **/
 static gboolean
 gcm_calibrate_printer (GcmCalibrate *calibrate, CdDevice *device, GtkWindow *window, GError **error)
 {
-	gboolean ret = FALSE;
 	gchar *ptr;
 	GtkWindow *window_tmp = NULL;
-	gchar *precision = NULL;
+	g_autofree gchar *precision = NULL;
 	const gchar *filename_tmp;
-	gchar *ti1_dest_fn = NULL;
-	gchar *ti1_src_fn = NULL;
+	g_autofree gchar *ti1_dest_fn = NULL;
+	g_autofree gchar *ti1_src_fn = NULL;
 	GcmCalibrateClass *klass = GCM_CALIBRATE_GET_CLASS (calibrate);
 	GcmCalibratePrivate *priv = GET_PRIVATE (calibrate);
 
@@ -860,9 +771,8 @@ gcm_calibrate_printer (GcmCalibrate *calibrate, CdDevice *device, GtkWindow *win
 		g_assert_not_reached ();
 	}
 	ti1_src_fn = g_build_filename (GCM_DATA, "ti1", filename_tmp, NULL);
-	ret = gcm_calibrate_copy_file (ti1_src_fn, ti1_dest_fn, error);
-	if (!ret)
-		goto out;
+	if (!gcm_calibrate_copy_file (ti1_src_fn, ti1_dest_fn, error))
+		return FALSE;
 
 	/* copy */
 	if (priv->print_kind == GCM_CALIBRATE_PRINT_KIND_ANALYZE) {
@@ -878,8 +788,7 @@ gcm_calibrate_printer (GcmCalibrate *calibrate, CdDevice *device, GtkWindow *win
 					     GCM_CALIBRATE_ERROR,
 					     GCM_CALIBRATE_ERROR_USER_ABORT,
 					     "user did not choose folder");
-			ret = FALSE;
-			goto out;
+			return FALSE;
 		}
 
 		/* reprogram the basename */
@@ -898,21 +807,13 @@ gcm_calibrate_printer (GcmCalibrate *calibrate, CdDevice *device, GtkWindow *win
 				     GCM_CALIBRATE_ERROR,
 				     GCM_CALIBRATE_ERROR_INTERNAL,
 				     "no klass support");
-		goto out;
+		return FALSE;
 	}
 
 	/* proxy */
-	ret = klass->calibrate_printer (calibrate, device, priv->sensor, window, error);
-out:
-	g_free (ti1_src_fn);
-	g_free (ti1_dest_fn);
-	g_free (precision);
-	return ret;
+	return klass->calibrate_printer (calibrate, device, priv->sensor, window, error);
 }
 
-/**
- * gcm_calibrate_get_enabled:
- **/
 gboolean
 gcm_calibrate_get_enabled (GcmCalibrate *calibrate)
 {
@@ -922,9 +823,6 @@ gcm_calibrate_get_enabled (GcmCalibrate *calibrate)
 	return TRUE;
 }
 
-/**
- * gcm_calibrate_get_reference_cie:
- **/
 static const gchar *
 gcm_calibrate_get_reference_cie (GcmCalibrateReferenceKind kind)
 {
@@ -937,22 +835,19 @@ gcm_calibrate_get_reference_cie (GcmCalibrateReferenceKind kind)
 	return NULL;
 }
 
-/**
- * gcm_calibrate_camera:
- **/
 static gboolean
 gcm_calibrate_camera (GcmCalibrate *calibrate, CdDevice *device, GtkWindow *window, GError **error)
 {
 	gboolean ret = FALSE;
 	gboolean has_shared_targets = TRUE;
-	gchar *reference_image = NULL;
-	gchar *reference_data = NULL;
-	gchar *device_str = NULL;
+	g_autofree gchar *reference_image = NULL;
+	g_autofree gchar *reference_data = NULL;
+	g_autofree gchar *device_str = NULL;
 	const gchar *directory;
 	const gchar *tmp;
-	GString *string;
+	g_autoptr(GString) string = NULL;
 	GtkWindow *window_tmp = NULL;
-	gchar *precision = NULL;
+	g_autofree gchar *precision = NULL;
 	GcmCalibratePrivate *priv = GET_PRIVATE (calibrate);
 	GcmCalibrateClass *klass = GCM_CALIBRATE_GET_CLASS (calibrate);
 
@@ -966,8 +861,7 @@ gcm_calibrate_camera (GcmCalibrate *calibrate, CdDevice *device, GtkWindow *wind
 				     GCM_CALIBRATE_ERROR,
 				     GCM_CALIBRATE_ERROR_USER_ABORT,
 				     "could not get calibration target image");
-		ret = FALSE;
-		goto out;
+		return FALSE;
 	}
 
 	/* use the exif data if there is any present */
@@ -992,8 +886,7 @@ gcm_calibrate_camera (GcmCalibrate *calibrate, CdDevice *device, GtkWindow *wind
 					     GCM_CALIBRATE_ERROR,
 					     GCM_CALIBRATE_ERROR_USER_ABORT,
 					     "could not get reference target");
-			ret = FALSE;
-			goto out;
+			return FALSE;
 		}
 	}
 
@@ -1015,24 +908,13 @@ gcm_calibrate_camera (GcmCalibrate *calibrate, CdDevice *device, GtkWindow *wind
 				     GCM_CALIBRATE_ERROR,
 				     GCM_CALIBRATE_ERROR_INTERNAL,
 				     "no klass support");
-		goto out;
+		return FALSE;
 	}
 
 	/* proxy */
-	ret = klass->calibrate_device (calibrate, device, priv->sensor, window, error);
-out:
-	if (string != NULL)
-		g_string_free (string, TRUE);
-	g_free (precision);
-	g_free (device_str);
-	g_free (reference_image);
-	g_free (reference_data);
-	return ret;
+	return klass->calibrate_device (calibrate, device, priv->sensor, window, error);
 }
 
-/**
- * gcm_calibrate_device:
- **/
 gboolean
 gcm_calibrate_device (GcmCalibrate *calibrate,
 		      CdDevice *device,
@@ -1157,9 +1039,6 @@ gcm_calibrate_interaction_required (GcmCalibrate *calibrate, const gchar *button
 	g_signal_emit (calibrate, signals[SIGNAL_INTERACTION_REQUIRED], 0, button_text);
 }
 
-/**
- * gcm_calibrate_get_property:
- **/
 static void
 gcm_calibrate_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec)
 {
@@ -1232,9 +1111,6 @@ gcm_calibrate_get_property (GObject *object, guint prop_id, GValue *value, GPara
 }
 
 
-/**
- * gcm_calibrate_set_property:
- **/
 static void
 gcm_calibrate_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec)
 {
@@ -1315,9 +1191,6 @@ gcm_calibrate_set_property (GObject *object, guint prop_id, const GValue *value,
 	}
 }
 
-/**
- * gcm_calibrate_class_init:
- **/
 static void
 gcm_calibrate_class_init (GcmCalibrateClass *klass)
 {
@@ -1454,9 +1327,6 @@ gcm_calibrate_class_init (GcmCalibrateClass *klass)
 			      G_TYPE_NONE, 1, G_TYPE_STRING);
 }
 
-/**
- * gcm_calibrate_init:
- **/
 static void
 gcm_calibrate_init (GcmCalibrate *calibrate)
 {
@@ -1472,9 +1342,6 @@ gcm_calibrate_init (GcmCalibrate *calibrate)
 	priv->working_path = g_strdup ("/tmp");
 }
 
-/**
- * gcm_calibrate_finalize:
- **/
 static void
 gcm_calibrate_finalize (GObject *object)
 {
@@ -1502,11 +1369,6 @@ gcm_calibrate_finalize (GObject *object)
 	G_OBJECT_CLASS (gcm_calibrate_parent_class)->finalize (object);
 }
 
-/**
- * gcm_calibrate_new:
- *
- * Return value: a new GcmCalibrate object.
- **/
 GcmCalibrate *
 gcm_calibrate_new (void)
 {
