@@ -90,9 +90,6 @@ enum {
 #define GCM_VIEWER_TREEVIEW_WIDTH		350 /* px */
 #define GCM_VIEWER_MAX_EXAMPLE_IMAGES		4
 
-/**
- * gcm_viewer_error_dialog:
- **/
 static void
 gcm_viewer_error_dialog (GcmViewerPrivate *viewer, const gchar *title, const gchar *message)
 {
@@ -107,9 +104,6 @@ gcm_viewer_error_dialog (GcmViewerPrivate *viewer, const gchar *title, const gch
 	gtk_widget_destroy (dialog);
 }
 
-/**
- * gcm_viewer_set_example_image:
- **/
 static void
 gcm_viewer_set_example_image (GcmViewerPrivate *viewer, GtkImage *image)
 {
@@ -118,7 +112,7 @@ gcm_viewer_set_example_image (GcmViewerPrivate *viewer, GtkImage *image)
 	g_autoptr(GdkPixbuf) pixbuf = NULL;
 	g_autoptr(GError) error = NULL;
 
-	filename = g_strdup_printf ("viewer-example-%02i.png", viewer->example_index);
+	filename = g_strdup_printf ("viewer-example-%02u.png", viewer->example_index);
 	path = g_build_filename (GCM_DATA, "figures", filename, NULL);
 	pixbuf = gdk_pixbuf_new_from_file (path, &error);
 	if (pixbuf == NULL) {
@@ -128,9 +122,6 @@ gcm_viewer_set_example_image (GcmViewerPrivate *viewer, GtkImage *image)
 	gtk_image_set_from_pixbuf (image, pixbuf);
 }
 
-/**
- * gcm_viewer_image_next_cb:
- **/
 static void
 gcm_viewer_image_next_cb (GtkWidget *widget, GcmViewerPrivate *viewer)
 {
@@ -141,9 +132,6 @@ gcm_viewer_image_next_cb (GtkWidget *widget, GcmViewerPrivate *viewer)
 	gcm_viewer_set_example_image (viewer, GTK_IMAGE (viewer->preview_widget_output));
 }
 
-/**
- * gcm_viewer_image_prev_cb:
- **/
 static void
 gcm_viewer_image_prev_cb (GtkWidget *widget, GcmViewerPrivate *viewer)
 {
@@ -154,9 +142,6 @@ gcm_viewer_image_prev_cb (GtkWidget *widget, GcmViewerPrivate *viewer)
 	gcm_viewer_set_example_image (viewer, GTK_IMAGE (viewer->preview_widget_output));
 }
 
-/**
- * gcm_viewer_profile_kind_to_icon_name:
- **/
 static const gchar *
 gcm_viewer_profile_kind_to_icon_name (CdProfileKind kind)
 {
@@ -175,9 +160,6 @@ gcm_viewer_profile_kind_to_icon_name (CdProfileKind kind)
 	return "image-missing";
 }
 
-/**
- * gcm_viewer_profile_get_sort_string:
- **/
 static const gchar *
 gcm_viewer_profile_get_sort_string (CdProfile *profile)
 {
@@ -217,9 +199,6 @@ gcm_viewer_profile_get_sort_string (CdProfile *profile)
 	return sort;
 }
 
-/**
- * gcm_viewer_update_profile_connect_cb:
- **/
 static void
 gcm_viewer_update_profile_connect_cb (GObject *source_object,
 				      GAsyncResult *res,
@@ -277,9 +256,6 @@ gcm_viewer_update_profile_connect_cb (GObject *source_object,
 	}
 }
 
-/**
- * gcm_viewer_update_get_profiles_cb:
- **/
 static void
 gcm_viewer_update_get_profiles_cb (GObject *source_object,
 				   GAsyncResult *res,
@@ -317,9 +293,6 @@ gcm_viewer_update_get_profiles_cb (GObject *source_object,
 	}
 }
 
-/**
- * gcm_viewer_update_profile_list:
- **/
 static void
 gcm_viewer_update_profile_list (GcmViewerPrivate *viewer)
 {
@@ -332,9 +305,6 @@ gcm_viewer_update_profile_list (GcmViewerPrivate *viewer)
 				viewer);
 }
 
-/**
- * gcm_viewer_profile_delete_cb:
- **/
 static void
 gcm_viewer_profile_delete_cb (GtkWidget *widget, GcmViewerPrivate *viewer)
 {
@@ -387,9 +357,6 @@ gcm_viewer_profile_delete_cb (GtkWidget *widget, GcmViewerPrivate *viewer)
 	}
 }
 
-/**
- * gcm_viewer_file_chooser_get_icc_profile:
- **/
 static GFile *
 gcm_viewer_file_chooser_get_icc_profile (GcmViewerPrivate *viewer)
 {
@@ -443,9 +410,6 @@ gcm_viewer_file_chooser_get_icc_profile (GcmViewerPrivate *viewer)
 	return file;
 }
 
-/**
- * gcm_viewer_profile_import_file:
- **/
 static gboolean
 gcm_viewer_profile_import_file (GcmViewerPrivate *viewer, GFile *file)
 {
@@ -465,9 +429,6 @@ gcm_viewer_profile_import_file (GcmViewerPrivate *viewer, GFile *file)
 	return TRUE;
 }
 
-/**
- * gcm_viewer_profile_import_cb:
- **/
 static void
 gcm_viewer_profile_import_cb (GtkWidget *widget, GcmViewerPrivate *viewer)
 {
@@ -484,15 +445,11 @@ gcm_viewer_profile_import_cb (GtkWidget *widget, GcmViewerPrivate *viewer)
 	gcm_viewer_profile_import_file (viewer, file);
 }
 
-/**
- * gcm_viewer_drag_data_received_cb:
- **/
 static void
 gcm_viewer_drag_data_received_cb (GtkWidget *widget, GdkDragContext *context, gint x, gint y, GtkSelectionData *data, guint _time, GcmViewerPrivate *viewer)
 {
 	const guchar *filename;
-	gchar **filenames = NULL;
-	GFile *file = NULL;
+	g_auto(GStrv) filenames = NULL;
 	guint i;
 	gboolean ret;
 	gboolean success = FALSE;
@@ -508,6 +465,7 @@ gcm_viewer_drag_data_received_cb (GtkWidget *widget, GdkDragContext *context, gi
 	/* split, as multiple drag targets are accepted */
 	filenames = g_strsplit_set ((const gchar *)filename, "\r\n", -1);
 	for (i = 0; filenames[i]!=NULL; i++) {
+		g_autoptr(GFile) file = NULL;
 
 		/* blank entry */
 		if (filenames[i][0] == '\0')
@@ -520,18 +478,12 @@ gcm_viewer_drag_data_received_cb (GtkWidget *widget, GdkDragContext *context, gi
 		ret = gcm_viewer_profile_import_file (viewer, file);
 		if (ret)
 			success = TRUE;
-
-		g_object_unref (file);
 	}
 
 out:
 	gtk_drag_finish (context, success, FALSE, _time);
-	g_strfreev (filenames);
 }
 
-/**
- * gcm_window_set_parent_xid:
- **/
 static void
 gcm_window_set_parent_xid (GtkWindow *window, guint32 xid)
 {
@@ -559,9 +511,6 @@ gcm_window_set_parent_xid (GtkWindow *window, guint32 xid)
 	gtk_window_set_title (window, "");
 }
 
-/**
- * gcm_viewer_add_profiles_columns:
- **/
 static void
 gcm_viewer_add_profiles_columns (GcmViewerPrivate *viewer, GtkTreeView *treeview)
 {
@@ -595,9 +544,6 @@ gcm_viewer_add_profiles_columns (GcmViewerPrivate *viewer, GtkTreeView *treeview
 	gtk_tree_view_column_set_expand (column, TRUE);
 }
 
-/**
- * gcm_viewer_profile_kind_to_string:
- **/
 static gchar *
 gcm_viewer_profile_kind_to_string (CdProfileKind kind)
 {
@@ -633,9 +579,6 @@ gcm_viewer_profile_kind_to_string (CdProfileKind kind)
 	return _("Unknown");
 }
 
-/**
- * gcm_viewer_profile_colorspace_to_string:
- **/
 static gchar *
 gcm_viewer_profile_colorspace_to_string (CdColorspace colorspace)
 {
@@ -683,9 +626,6 @@ gcm_viewer_profile_colorspace_to_string (CdColorspace colorspace)
 	return _("Unknown");
 }
 
-/**
- * gcm_viewer_add_named_colors:
- **/
 static gboolean
 gcm_viewer_add_named_colors (GcmViewerPrivate *viewer, CdIcc *icc)
 {
@@ -803,9 +743,6 @@ gcm_viewer_is_blacklisted_metadata_key (const gchar *key)
 	return TRUE;
 }
 
-/**
- * gcm_viewer_add_metadata:
- **/
 static gboolean
 gcm_viewer_add_metadata (GcmViewerPrivate *viewer,
 			 CdProfile *profile)
@@ -852,9 +789,6 @@ gcm_viewer_add_metadata (GcmViewerPrivate *viewer,
 	return TRUE;
 }
 
-/**
- * cd_icc_warning_to_string:
- **/
 static const gchar *
 cd_icc_warning_to_string (CdProfileWarning kind_enum)
 {
@@ -912,9 +846,6 @@ cd_icc_warning_to_string (CdProfileWarning kind_enum)
 	return kind;
 }
 
-/**
- * gcm_viewer_set_profile:
- **/
 static void
 gcm_viewer_set_profile (GcmViewerPrivate *viewer, CdProfile *profile)
 {
@@ -1102,11 +1033,11 @@ gcm_viewer_set_profile (GcmViewerPrivate *viewer, CdProfile *profile)
 	gtk_widget_set_visible (widget, temperature > 0);
 	if (temperature > 0) {
 		if (fabs (temperature - 5000) < 10) {
-			temp = g_strdup_printf ("%iK (D50)", temperature);
+			temp = g_strdup_printf ("%uK (D50)", temperature);
 		} else if (fabs (temperature - 6500) < 10) {
-			temp = g_strdup_printf ("%iK (D65)", temperature);
+			temp = g_strdup_printf ("%uK (D65)", temperature);
 		} else {
-			temp = g_strdup_printf ("%iK", temperature);
+			temp = g_strdup_printf ("%uK", temperature);
 		}
 		gtk_label_set_label (GTK_LABEL (widget), temp);
 		g_free (temp);
@@ -1203,16 +1134,13 @@ gcm_viewer_set_profile (GcmViewerPrivate *viewer, CdProfile *profile)
 	gtk_widget_set_visible (widget, show_section_from);
 }
 
-/**
- * gcm_viewer_profiles_treeview_clicked_cb:
- **/
 static void
 gcm_viewer_profiles_treeview_clicked_cb (GtkTreeSelection *selection,
 					 GcmViewerPrivate *viewer)
 {
 	GtkTreeModel *model;
 	GtkTreeIter iter;
-	CdProfile *profile;
+	g_autoptr(CdProfile) profile = NULL;
 
 	/* ignore */
 	if (viewer->clearing_store)
@@ -1229,12 +1157,8 @@ gcm_viewer_profiles_treeview_clicked_cb (GtkTreeSelection *selection,
 			    GCM_PROFILES_COLUMN_PROFILE, &profile,
 			    -1);
 	gcm_viewer_set_profile (viewer, profile);
-	g_object_unref (profile);
 }
 
-/**
- * gcm_viewer_client_profile_added_cb:
- **/
 static void
 gcm_viewer_client_profile_added_cb (CdClient *client,
 				    CdProfile *profile,
@@ -1245,9 +1169,6 @@ gcm_viewer_client_profile_added_cb (CdClient *client,
 	gcm_viewer_update_profile_list (viewer);
 }
 
-/**
- * gcm_viewer_client_profile_removed_cb:
- **/
 static void
 gcm_viewer_client_profile_removed_cb (CdClient *client,
 				      CdProfile *profile,
@@ -1258,9 +1179,6 @@ gcm_viewer_client_profile_removed_cb (CdClient *client,
 	gcm_viewer_update_profile_list (viewer);
 }
 
-/**
- * gcm_viewer_setup_drag_and_drop:
- **/
 static void
 gcm_viewer_setup_drag_and_drop (GtkWidget *widget)
 {
@@ -1275,9 +1193,6 @@ gcm_viewer_setup_drag_and_drop (GtkWidget *widget)
 	g_free (entry.target);
 }
 
-/**
- * gcm_viewer_activate_cb:
- **/
 static void
 gcm_viewer_activate_cb (GApplication *application, GcmViewerPrivate *viewer)
 {
@@ -1347,18 +1262,12 @@ gcm_viewer_add_metadata_columns (GcmViewerPrivate *viewer,
 	gtk_tree_view_column_set_expand (column, TRUE);
 }
 
-/**
- * gcm_viewer_named_color_treeview_clicked:
- **/
 static void
 gcm_viewer_named_color_treeview_clicked (GtkTreeSelection *selection, GcmViewerPrivate *viewer)
 {
 	g_debug ("named color changed");
 }
 
-/**
- * gcm_viewer_show_single_profile_by_filename:
- **/
 static void
 gcm_viewer_show_single_profile_by_filename (GcmViewerPrivate *viewer,
 					    const gchar *filename)
@@ -1419,9 +1328,6 @@ gcm_viewer_show_single_profile_by_filename (GcmViewerPrivate *viewer,
 	gcm_viewer_set_profile (viewer, profile);
 }
 
-/**
- * gcm_viewer_show_single_profile_by_id:
- **/
 static void
 gcm_viewer_show_single_profile_by_id (GcmViewerPrivate *viewer,
 				      const gchar *id)
@@ -1443,9 +1349,6 @@ gcm_viewer_show_single_profile_by_id (GcmViewerPrivate *viewer,
 	gcm_viewer_set_profile (viewer, profile);
 }
 
-/**
- * gcm_viewer_startup_cb:
- **/
 static void
 gcm_viewer_startup_cb (GApplication *application, GcmViewerPrivate *viewer)
 {
@@ -1662,7 +1565,7 @@ gcm_viewer_startup_cb (GApplication *application, GcmViewerPrivate *viewer)
 
 	/* set the parent window if it is specified */
 	if (viewer->xid != 0) {
-		g_debug ("Setting xid %i", viewer->xid);
+		g_debug ("Setting xid %u", viewer->xid);
 		gcm_window_set_parent_xid (GTK_WINDOW (main_window), viewer->xid);
 	}
 
@@ -1693,9 +1596,6 @@ gcm_viewer_startup_cb (GApplication *application, GcmViewerPrivate *viewer)
 	gcm_viewer_update_profile_list (viewer);
 }
 
-/**
- * main:
- **/
 int
 main (int argc, char **argv)
 {
@@ -1706,7 +1606,7 @@ main (int argc, char **argv)
 	guint xid = 0;
 	int status = 0;
 	gboolean ret;
-	GError *error = NULL;
+	g_autoptr(GError) error = NULL;
 
 	const GOptionEntry options[] = {
 		{ "parent-window", 'p', 0, G_OPTION_ARG_INT, &xid,
@@ -1736,7 +1636,6 @@ main (int argc, char **argv)
 	ret = g_option_context_parse (context, &argc, &argv, &error);
 	if (!ret) {
 		g_warning ("failed to parse options: %s", error->message);
-		g_error_free (error);
 	}
 	g_option_context_free (context);
 
